@@ -1,6 +1,4 @@
 /*
- * kinit/initrd.c
- *
  * Handle initrd, thus putting the backwards into backwards compatible
  */
 
@@ -115,7 +113,7 @@ static int run_linuxrc(int argc, char *argv[], dev_t root_dev)
 	    mount(".", "/", NULL, MS_MOVE, NULL) || chroot("."))
 		return -errno;
 
-	pid = fork();
+	pid = vfork();
 	if (pid == 0) {
 		setsid();
 		/* Looks like linuxrc doesn't get the init environment
